@@ -563,15 +563,24 @@ _ansi_sgr_groups = tuple(
     set(map(str, itertools.chain.from_iterable(ranges)))
     for ranges
     in (
-        (range(30, 39), range(90, 98)),
-        (range(40, 49), range(100, 108)),
-        (range(11, 20),),
+        ((1, 21, 22),),
+        ((2, 22,),),
         ((3, 23),),
-        ((20, 23),),
+        ((4, 24),),
+        ((5, 25),),
+        ((6, 25),),
+        ((7, 27),),
+        ((8, 28),),
         ((9, 29),),
+        ((10,), range(11, 20)),
+        ((20, 23),),
+        (range(30, 40), range(90, 98)),
+        (range(40, 50), range(100, 108)),
+        ((26, 50),)
         ((51, 54),),
         ((52, 54),),
         ((53, 55),)
+        ((58, 59),)
     )
 )
 
@@ -593,7 +602,7 @@ del _ansi_sgr_groups
 
 def _ansi_sgr_mutate(last, next, family = _check_sgr_group_family):
 
-    if not len(last) > 0:
+    if not last:
         last.append(next)
         return
 
